from network import Network
import numpy as np
import torch

def load_net(fname, net):
    import h5py
    h5f = h5py.File(fname, mode='r')
    for k, v in net.state_dict().items():        
        param = torch.from_numpy(np.asarray(h5f[k]))         
        v.copy_(param)

def evaluate_model(trained_model, data_loader,batchSize, index):
    net = Network(index)
    load_net(trained_model, net)
    net.cuda()
    net.eval()
    count = 0
    total = 0
    idx = 0 
    step = -1
    dataCount = len(data_loader) 

    curvation_data  = [] 
    img_data        = []
    wetidx_data     = [] 
    flowacc_data    = [] 

    for blob in data_loader:                        
        step      = step+1
        data      = blob['data']
        dem       = blob['dem']
        slope     = blob['slope']
        img       = blob['imgg']
        #curvation = blob['curvation']
        #wetidx    = blob['wetidx']
        #flowacc   = blob['flowacc'] 
        
        label     = blob['label']

        if idx==0:
           im_data    = data 
           dem_data   = dem 
           slope_data = slope 
           img_data       = img
           
           gt_data    = np.array( label) 
           gt_data    = gt_data.reshape( 1, 1 )

        else:
           im_data        =np.concatenate([im_data,data],axis=0)
           dem_data       =np.concatenate([dem_data,dem],axis=0)
           slope_data     =np.concatenate([slope_data,slope],axis=0)
           img_data       = np.concatenate([img_data,img],axis=0)
           

           label = np.array( label) 
           label = label.reshape( 1, 1 )
           gt_data =np.concatenate([gt_data,label],axis=0)

        idx = idx+1
        if idx<batchSize:
            if step<dataCount-1:
               continue

        idx = 0

        #pre_label,featuremap = net(im_data,dem ,slope,index, gt_data)
        pre_label,featuremap = net(im_data,dem_data ,slope_data, curvation_data,img_data,wetidx_data,flowacc_data,index, gt_data)
        pre_label = pre_label.data.cpu().numpy()

        label = pre_label.argmax(axis=1).flatten()
        num = len(label)
        
        for i in range(0,num):
            if gt_data[i] == label[i]:
               count = count+1
            total = total+1

    return 1.0*count/total




